@@ -1,8 +1,10 @@
+from emout.utils.util import hole_mask
 import re
 from itertools import chain
 from pathlib import Path
+from typing import Callable, Union
 
-import emout.plot as emplt
+import emout.plot.basic_plot as emplt
 import emout.utils as utils
 import h5py
 import matplotlib.animation as animation
@@ -891,7 +893,7 @@ class Data(np.ndarray):
         to_axis = {3: 'x', 2: 'y', 1: 'z', 0: 't'}
         return list(map(lambda a: to_axis[a], self.slice_axes))
 
-    def masked(self, mask):
+    def masked(self, mask: Union[np.ndarray, Callable[[np.ndarray], np.ndarray]]):
         """マスクされたデータを返す.
 
         Parameters
@@ -926,7 +928,7 @@ class Data(np.ndarray):
                 title=None,
                 notitle=False,
                 offsets=None,
-                use_si=False,
+                use_si=True,
                 vmin=None,
                 vmax=None,
                 **kwargs):
@@ -939,7 +941,7 @@ class Data(np.ndarray):
         axis : int, optional
             アニメーションする軸, by default 0
         show : bool, optional
-            プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
+            プロットを表示する場合True(ファイルに保存する場合は非表示), by default True
         savefilename : str, optional
             保存するファイル名(Noneの場合保存しない), by default None
         interval : int, optional
@@ -982,7 +984,7 @@ class Data(np.ndarray):
                 slc = self.slices[ax]
                 maxlen = self.shape[axis]
 
-                line = np.array(utils.range_with_slice(slc, maxlen=maxlen))
+                line = np.array(utils.range_with_slice(slc, maxlen=maxlen), dtype=float)
 
                 if offsets is not None:
                     line = _offseted(line, offsets[0])
@@ -1119,7 +1121,7 @@ class Data2d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(self, axes='auto', show=False, use_si=False, offsets=None, mode='cm', **kwargs):
+    def plot(self, axes='auto', show=False, use_si=True, offsets=None, mode='cm', **kwargs):
         """2次元データをプロットする.
 
         Parameters
@@ -1129,7 +1131,7 @@ class Data2d(Data):
         show : bool
             プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
         use_si : bool
-            SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
+            SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default True
         offsets : (float or str, float or str, float or str)
             プロットのx,y,z軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
         mode : str
@@ -1247,7 +1249,7 @@ class Data2d(Data):
                 z = _offseted(z, offsets[2])
                 val = _offseted(val, offsets[3])
 
-            imgs = emplt.plot_surface(x, y, z, val, **kwargs)
+            imgs = [emplt.plot_surface(x, y, z, val, **kwargs)]
         else:
             if offsets is not None:
                 x = _offseted(x, offsets[0])
@@ -1296,7 +1298,7 @@ class Data1d(Data):
 
         return super().__new__(cls, input_array, **kwargs)
 
-    def plot(self, show=False, use_si=False, offsets=None, **kwargs):
+    def plot(self, show=False, use_si=True, offsets=None, **kwargs):
         """1次元データをプロットする.
 
         Parameters
@@ -1304,7 +1306,7 @@ class Data1d(Data):
         show : bool
             プロットを表示する場合True(ファイルに保存する場合は非表示), by default False
         use_si : bool
-            SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default False
+            SI単位系を用いる場合True(そうでない場合EMSES単位系を用いる), by default True
         offsets : (float or str, float or str)
             プロットのx,y軸のオフセット('left': 最初を0, 'center': 中心を0, 'right': 最後尾を0, float: 値だけずらす), by default None
         savefilename : str, optional
@@ -1395,7 +1397,7 @@ class VectorData2d(utils.Group):
             return
         super().__setattr__(key, value)
 
-    def plot(self, axes='auto', show=False, use_si=False, offsets=None, **kwargs):
+    def plot(self, axes='auto', show=False, use_si=True, offsets=None, **kwargs):
         """2次元データをプロットする.
 
         Parameters
@@ -1462,8 +1464,8 @@ class VectorData2d(utils.Group):
         axis1 = self.objs[0].slice_axes[self.objs[0].use_axes.index(axes[0])]
         axis2 = self.objs[0].slice_axes[self.objs[0].use_axes.index(axes[1])]
 
-        x = np.arange(*utils.slice2tuple(self.objs[0].slices[axis1]))
-        y = np.arange(*utils.slice2tuple(self.objs[0].slices[axis2]))
+        x = np.arange(*utils.slice2tuple(self.objs[0].slices[axis1]), dtype=float)
+        y = np.arange(*utils.slice2tuple(self.objs[0].slices[axis2]), dtype=float)
 
         if use_si:
             xunit = self.objs[0].axisunits[axis1]
@@ -1489,6 +1491,7 @@ class VectorData2d(utils.Group):
             y_data = self.y_data
 
         def _offseted(line, offset):
+            line = line.astype(float)
             if offset == 'left':
                 line -= line[0]
             elif offset == 'center':
